@@ -10,11 +10,11 @@ def clean(hub, root_dir: pathlib.Path):
     clean everything up
     """
     ret = subprocess.run(
-        [sys.executable, root_dir / "setup.py", "--no-user-cfg", "--quiet", "clean"]
+        [sys.executable, str(root_dir / "setup.py"), "--no-user-cfg", "--quiet", "clean"]
     )
     ret.check_returncode()
     try:
-        shutil.rmtree(root_dir / "dist")
+        shutil.rmtree(str(root_dir / "dist"))
     except FileNotFoundError:
         ...
 
@@ -26,7 +26,7 @@ def build(hub, root_dir: pathlib.Path):
     ret = subprocess.run(
         [
             sys.executable,
-            root_dir / "setup.py",
+            str(root_dir / "setup.py"),
             "--no-user-cfg",
             "--quiet",
             "sdist",
