@@ -57,10 +57,10 @@ async def run(
     if "test" not in skip:
         print("Running tests")
         hub.pop_release.test.pytest(root_path)
-    if "commit" not in skip:
+    if "commit" not in skip and "git" not in skip:
         print("Committing changes")
         hub.pop_release.git.commit(root_path, version)
-    if "tag" not in skip:
+    if "tag" not in skip and "git" not in skip:
         print("Tagging commit")
         hub.pop_release.git.tag(root_path, version)
     if "clean" not in skip:
@@ -79,7 +79,7 @@ async def run(
         if "release" not in skip:
             print("Releasing to repository")
             await hub.pop_release.twine.push(ctx, root_path)
-        if "push" not in skip:
+        if "push" not in skip and "git" not in skip:
             print(f"Pushing to git remote: {remote}")
             hub.pop_release.git.push(root_path, remote)
     print("Success!")
